SchedulerConfig

Struct SchedulerConfig 

pub struct SchedulerConfig {
    pub policy: SchedulePolicy,
    pub clock: ClockMode,
    pub default_channel_capacity: usize,
    pub preempt_every: u32,
    pub workers: usize,
}
All scheduler knobs, bundled. Has a Default and fluent setters so it is easy to annotate while still having a sensible baseline.

Fields

policy: SchedulePolicy

Ready-task selection discipline (default Fifo).

clock: ClockMode

Clock mode (default Logical).

default_channel_capacity: usize

Default capacity for channels created without an explicit one (default 32 — matches the AOT mpsc default).

preempt_every: u32

Cooperative yield interval, in scheduler steps (default 10_000).

workers: usize

M:N worker count; 1 = cooperative single-thread (default 1).

Implementations

Source

impl SchedulerConfig

pub fn with_policy(self, policy: SchedulePolicy) -> Self

Set the scheduling policy.

pub fn with_clock(self, clock: ClockMode) -> Self

Set the clock mode.

pub fn with_channel_capacity(self, capacity: usize) -> Self

Set the default channel capacity.

pub fn with_workers(self, workers: usize) -> Self

Set the worker count (M:N).